@@ -380,8 +380,10 @@ class Field:
             '        g_string_append_printf (printable, "Additional unexpected \'%" G_GSIZE_FORMAT "\' bytes", offset);\n'
             '\n'
             'out:\n'
-            '    if (error)\n'
+            '    if (error) {\n'
             '        g_string_append_printf (printable, " ERROR: %s", error->message);\n'
+            '        g_error_free (error);\n'
+            '    }\n'
             '    return g_string_free (printable, FALSE);\n'
             '}\n')
         f.write(string.Template(template).substitute(translations))
