@@ -28,7 +28,9 @@
 
 #include "qmi-device.h"
 #include "qmi-dms.h"
+#include "qmi-nas.h"
 #include "qmi-uim.h"
+#include "qmi-wda.h"
 #include "qmi-enums-nas.h"
 #include "qmi-enums-wms.h"
 
@@ -1378,6 +1380,110 @@ gboolean qmi_message_uim_change_pin_input_set_session_information (
     const gchar *value_session_information_application_identifier,
     GError **error);
 
+/**
+ * qmi_message_wda_get_data_format_output_get_uplink_data_aggregation_max_size:
+ * @self: a #QmiMessageWdaGetDataFormatOutput.
+ * @value_uplink_data_aggregation_max_size: a placeholder for the output #guint32, or %NULL if not required.
+ * @error: Return location for error or %NULL.
+ *
+ * Get the 'Uplink Data Aggregation Max Size' field from @self.
+ *
+ * Returns: %TRUE if the field is found, %FALSE otherwise.
+ *
+ * Since: 1.10
+ * Deprecated: 1.24.6: Use qmi_message_wda_get_data_format_output_get_downlink_data_aggregation_max_datagrams() instead.
+ */
+G_DEPRECATED_FOR (qmi_message_wda_get_data_format_output_get_downlink_data_aggregation_max_datagrams)
+gboolean qmi_message_wda_get_data_format_output_get_uplink_data_aggregation_max_size
+    (QmiMessageWdaGetDataFormatOutput *self,
+     guint32 *value_uplink_data_aggregation_max_size,
+     GError **error);
+
+/**
+ * qmi_message_nas_get_operator_name_output_get_operator_nitz_information:
+ * @self: a #QmiMessageNasGetOperatorNameOutput.
+ * @value_operator_nitz_information_name_encoding: a placeholder for the output #QmiNasPlmnEncodingScheme, or %NULL if not required.
+ * @value_operator_nitz_information_short_country_initials: a placeholder for the output #QmiNasPlmnNameCountryInitials, or %NULL if not required.
+ * @value_operator_nitz_information_long_name_spare_bits: a placeholder for the output #QmiNasPlmnNameSpareBits, or %NULL if not required.
+ * @value_operator_nitz_information_short_name_spare_bits: a placeholder for the output #QmiNasPlmnNameSpareBits, or %NULL if not required.
+ * @value_operator_nitz_information_long_name: a placeholder for the output constant string, or %NULL if not required.
+ * @value_operator_nitz_information_short_name: a placeholder for the output constant string, or %NULL if not required.
+ * @error: Return location for error or %NULL.
+ *
+ * Get the 'Operator NITZ Information' field from @self.
+ *
+ * Returns: %TRUE if the field is found, %FALSE otherwise.
+ *
+ * Since: 1.18
+ * Deprecated: 1.24.6: Use qmi_message_nas_get_operator_name_output_get_nitz_information() instead.
+ */
+G_DEPRECATED_FOR (qmi_message_nas_get_operator_name_output_get_nitz_information)
+gboolean qmi_message_nas_get_operator_name_output_get_operator_nitz_information (
+    QmiMessageNasGetOperatorNameOutput *self,
+    QmiNasPlmnEncodingScheme *value_operator_nitz_information_name_encoding,
+    QmiNasPlmnNameCountryInitials *value_operator_nitz_information_short_country_initials,
+    QmiNasPlmnNameSpareBits *value_operator_nitz_information_long_name_spare_bits,
+    QmiNasPlmnNameSpareBits *value_operator_nitz_information_short_name_spare_bits,
+    const gchar **value_operator_nitz_information_long_name,
+    const gchar **value_operator_nitz_information_short_name,
+    GError **error);
+
+/**
+ * qmi_indication_nas_operator_name_output_get_operator_nitz_information:
+ * @self: a #QmiIndicationNasOperatorNameOutput.
+ * @value_operator_nitz_information_name_encoding: a placeholder for the output #QmiNasPlmnEncodingScheme, or %NULL if not required.
+ * @value_operator_nitz_information_short_country_initials: a placeholder for the output #QmiNasPlmnNameCountryInitials, or %NULL if not required.
+ * @value_operator_nitz_information_long_name_spare_bits: a placeholder for the output #QmiNasPlmnNameSpareBits, or %NULL if not required.
+ * @value_operator_nitz_information_short_name_spare_bits: a placeholder for the output #QmiNasPlmnNameSpareBits, or %NULL if not required.
+ * @value_operator_nitz_information_long_name: a placeholder for the output constant string, or %NULL if not required.
+ * @value_operator_nitz_information_short_name: a placeholder for the output constant string, or %NULL if not required.
+ * @error: Return location for error or %NULL.
+ *
+ * Get the 'Operator NITZ Information' field from @self.
+ *
+ * Returns: %TRUE if the field is found, %FALSE otherwise.
+ *
+ * Since: 1.18
+ * Deprecated: 1.24.6: Use qmi_indication_nas_operator_name_output_get_nitz_information() instead.
+ */
+G_DEPRECATED_FOR (qmi_indication_nas_operator_name_output_get_nitz_information)
+gboolean qmi_indication_nas_operator_name_output_get_operator_nitz_information (
+    QmiIndicationNasOperatorNameOutput *self,
+    QmiNasPlmnEncodingScheme *value_operator_nitz_information_name_encoding,
+    QmiNasPlmnNameCountryInitials *value_operator_nitz_information_short_country_initials,
+    QmiNasPlmnNameSpareBits *value_operator_nitz_information_long_name_spare_bits,
+    QmiNasPlmnNameSpareBits *value_operator_nitz_information_short_name_spare_bits,
+    const gchar **value_operator_nitz_information_long_name,
+    const gchar **value_operator_nitz_information_short_name,
+    GError **error);
+
+/**
+ * qmi_message_nas_get_home_network_output_get_home_network_3gpp2:
+ * @self: a #QmiMessageNasGetHomeNetworkOutput.
+ * @value_home_network_3gpp2_mcc: a placeholder for the output #guint16, or %NULL if not required.
+ * @value_home_network_3gpp2_mnc: a placeholder for the output #guint16, or %NULL if not required.
+ * @value_home_network_3gpp2_display_description: a placeholder for the output #QmiNasNetworkDescriptionDisplay, or %NULL if not required.
+ * @value_home_network_3gpp2_description_encoding: a placeholder for the output #QmiNasNetworkDescriptionEncoding, or %NULL if not required.
+ * @value_home_network_3gpp2_description: a placeholder for the output constant string, or %NULL if not required.
+ * @error: Return location for error or %NULL.
+ *
+ * Get the 'Home Network 3GPP2' field from @self.
+ *
+ * Returns: %TRUE if the field is found, %FALSE otherwise.
+ *
+ * Since: 1.0
+ * Deprecated: 1.24.6: Use qmi_message_nas_get_home_network_output_get_home_network_3gpp2_ext() instead.
+ */
+G_DEPRECATED_FOR (qmi_message_nas_get_home_network_output_get_home_network_3gpp2_ext)
+gboolean qmi_message_nas_get_home_network_output_get_home_network_3gpp2 (
+    QmiMessageNasGetHomeNetworkOutput *self,
+    guint16 *value_home_network_3gpp2_mcc,
+    guint16 *value_home_network_3gpp2_mnc,
+    QmiNasNetworkDescriptionDisplay *value_home_network_3gpp2_display_description,
+    QmiNasNetworkDescriptionEncoding *value_home_network_3gpp2_description_encoding,
+    const gchar **value_home_network_3gpp2_description,
+    GError **error);
+
 #endif /* QMI_DISABLE_DEPRECATED */
 
 #endif /* _LIBQMI_GLIB_QMI_COMPAT_H_ */
