@@ -73,6 +73,7 @@
  * @QMI_CORE_ERROR_UNSUPPORTED: Not supported.
  * @QMI_CORE_ERROR_TLV_EMPTY: TLV has no value. Empty TLVs are not a real error, so this error type is never generated. Since: 1.12. Deprecated: 1.22.
  * @QMI_CORE_ERROR_UNEXPECTED_MESSAGE: QMI message is unexpected. Since: 1.16.
+ * @QMI_CORE_ERROR_INVALID_DATA: Invalid data found in the message. Since: 1.24.6.
  *
  * Common errors that may be reported by libqmi-glib.
  *
@@ -89,6 +90,7 @@ typedef enum { /*< underscore_name=qmi_core_error >*/
     QMI_CORE_ERROR_UNSUPPORTED        = 7, /*< nick=Unsupported >*/
     QMI_CORE_ERROR_TLV_EMPTY          = 8, /*< nick=TlvEmpty >*/
     QMI_CORE_ERROR_UNEXPECTED_MESSAGE = 9, /*< nick=UnexpectedMessage >*/
+    QMI_CORE_ERROR_INVALID_DATA       = 10, /*< nick=InvalidData >*/
 } QmiCoreError;
 
 /**
