@@ -74,6 +74,8 @@
  * @QMI_NAS_BAND_PREFERENCE_WCDMA_2600: WCDMA 2600.
  * @QMI_NAS_BAND_PREFERENCE_WCDMA_900: WCDMA 900.
  * @QMI_NAS_BAND_PREFERENCE_WCDMA_1700_JAPAN: WCDMA 1700 (Japan).
+ * @QMI_NAS_BAND_PREFERENCE_WCDMA_850_JAPAN: WCDMA 850 (Japan). Since: 1.22.
+ * @QMI_NAS_BAND_PREFERENCE_WCDMA_1500: WCDMA 1500. Since: 1.22.
  *
  * Flags to specify frequency band preferences.
  *
@@ -120,8 +122,10 @@ typedef enum {
     QMI_NAS_BAND_PREFERENCE_BC_16            = ((guint64) 1) << 56,
     QMI_NAS_BAND_PREFERENCE_BC_17            = ((guint64) 1) << 57,
     QMI_NAS_BAND_PREFERENCE_BC_18            = ((guint64) 1) << 58,
-    QMI_NAS_BAND_PREFERENCE_BC_19            = ((guint64) 1) << 59
-    /* Bits 60-63 reserved */
+    QMI_NAS_BAND_PREFERENCE_BC_19            = ((guint64) 1) << 59,
+    QMI_NAS_BAND_PREFERENCE_WCDMA_850_JAPAN  = ((guint64) 1) << 60,
+    QMI_NAS_BAND_PREFERENCE_WCDMA_1500       = ((guint64) 1) << 61
+    /* Bits 62-63 reserved */
 } QmiNasBandPreference;
 
 /**
@@ -153,6 +157,13 @@ typedef enum {
  * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_21: LTE EUTRAN Band 21.
  * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_24: LTE EUTRAN Band 24.
  * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_25: LTE EUTRAN Band 25.
+ * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_26: LTE EUTRAN Band 26.
+ * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_27: LTE EUTRAN Band 27.
+ * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_28: LTE EUTRAN Band 28.
+ * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_29: LTE EUTRAN Band 29.
+ * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_30: LTE EUTRAN Band 30.
+ * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_31: LTE EUTRAN Band 31.
+ * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_32: LTE EUTRAN Band 32.
  * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_33: LTE EUTRAN Band 33.
  * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_34: LTE EUTRAN Band 34.
  * @QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_35: LTE EUTRAN Band 35.
@@ -193,7 +204,13 @@ typedef enum {
     /* Bit 21-22 reserved */
     QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_24 = 1 << 23,
     QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_25 = 1 << 24,
-    /* Bit 25-31 reserved */
+    QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_26 = 1 << 25,
+    QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_27 = 1 << 26,
+    QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_28 = 1 << 27,
+    QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_29 = 1 << 28,
+    QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_30 = 1 << 29,
+    QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_31 = 1 << 30,
+    QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_32 = ((guint64) 1) << 31,
     QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_33 = ((guint64) 1) << 32,
     QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_34 = ((guint64) 1) << 33,
     QMI_NAS_LTE_BAND_PREFERENCE_EUTRAN_35 = ((guint64) 1) << 34,
